pcg

Function pcg 

pub fn pcg<T, A, P>(
    operator: &A,
    precond: &P,
    b: &Array1<T>,
    config: &CgConfig<T::Real>,
) -> CgSolution<T>
Solve Ax = b using the Preconditioned Conjugate Gradient method

Uses a preconditioner M to accelerate convergence. At each iteration, the preconditioner is applied as z = M^{-1} r, and the search direction is computed using the preconditioned residual.

Note: Both A and M^{-1} must be symmetric positive definite.