pub enum AmgInterpolation {
Standard,
Extended,
Direct,
}Expand description
Interpolation operator type
Variants
Standard
Standard interpolation - direct interpolation from coarse neighbors
Extended
Extended interpolation - includes indirect (distance-2) connections Better for some problem types but more expensive
Direct
Direct interpolation - simplest, only immediate strong connections Fastest but may have poor convergence for hard problems